<script setup lang="ts">

import {QueueApi, QueueVO} from "@/api/ecg/queue";
import {RoomBedVO} from "@/api/ecg/doctor";
import {DICT_TYPE} from "@/utils/dict";
import {RoomApi} from "@/api/ecg/room";

defineOptions({ name: 'roomscreen' })

const list = ref<QueueVO[]>([]) // 列表的数据

const roomBed : RoomBedVO = ref<RoomBedVO>({
  roomId : null,
  roomName: null,
  bedNo: null
})

const statusMap  = new Map([
  [20, "准备中"],
  [30, "就诊中"],
  [50, "过号"]
]);

const getList = async () => {
  const data = await QueueApi.getRoomScreenData()
  list.value = data
}

const getRoomByIp = async () => {
  const data = await RoomApi.getRoomByIP()
  roomBed.value = data
}

const startScrolling = () => {
  setInterval(() => {
    // console.info("...")
    getList()
  }, 3000); // 每两秒滚动一次
}

onMounted( () => {
  getRoomByIp()
  startScrolling()
})

</script>

<template>
  <el-container>
    <el-aside width="200px">Aside</el-aside>
    <el-container>
      <el-header>{{ roomBed.roomName }}</el-header>
      <el-main>
        <el-table
            :data="list"
            stripe
            :show-header="false"
            style="width: 100%">
          <el-table-column
              prop="patName"
              label="患者姓名"
              width="80"/>
          <el-table-column label="状态" align="center" :prop="status" width="80">
            <template #default="scope">
              {{ statusMap.get(scope.row.status) }}
            </template>
          </el-table-column>
        </el-table>
      </el-main>
      <el-footer>Footer</el-footer>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">

</style>
